#!/usr/bin/python

#doc:just run "mini_service2"

from test import start, finish
import sys

p = start('mini_service2', 2)
sys.exit(finish(p))
